********************************************************************************
********************************************************************************
*
* Title: Polygynous Neighbors, Excess Men and Intergroup Conflict in Rural Africa
* Authors: Carlo Koos, Clara Neupert-Wentz
* Publication: Journal of Conflict Resolution
*
* Replication Files for Section: 
* Mechanism: Frustration and Aggression among Excess Men"
*
********************************************************************************
********************************************************************************

* Load Afrobarometer data matched with ethnic identity and variables from the 
* Ethnographic Atlas (Murdock 1967). 
clear
*cd "<SPECIFY DATA DIRECTORY HERE>"
use afrobarometer.dta

********************************************************************************
* EXPLANATORY VARIABLES
* Code and label variables from Afrobarometer data
********************************************************************************
* female dummy
gen female=.
replace female=0 if q101==1
replace female=1 if q101==2
* age and age2
label var age "Age"
gen age2=age*age
label var age2 "Age2"
* urban/rural dummy
gen urban_dum=.
replace urban_dum=0 if urbrur==2
replace urban_dum=1 if urbrur==1
label var urban_dum "Urban"
* create simple asset index by first changing don't knows ("9") to "0" and 
* dropping missing data ("-1") and refusal ("998")
foreach var of varlist q93a q93b q93c q93d q93e q93f {
  recode `var' (9 = 0) (-1 998 = .), gen(`var'_rec) //
}
gen assets=(q93a_rec+ q93b_rec+ q93c_rec +q93d_rec +q93e_rec +q93f_rec)
label var assets "Assets"
* education (drop missings ("-1) and don't knows ("99")
recode q90 (-1 = .) (99 = 0), gen(edu)
label var edu "Education level"
* no children (unfortunately and surprisingly this Afrobarometer wave did not 
* include information on marriage status and the number of children of the 
* respondent. One question (Q8f asked about difficulties in paying school 
* expenses. One response option was "no children" (7) which indicates whether a
* respondent has children.
g nochildren=0
replace nochildren=1 if q8f==7
label var nochildren "No children"

********************************************************************************
* OUTCOME VARIABLES
* Code and label variables from Afrobarometer data
********************************************************************************

recode q51 (-1 9 = .) (3 4 5=1) (  1 2 =0), gen(use_violence_d)
label var use_violence_d "Violence justified"
recode q53d (-1 9 = .), gen(treated_unequally)
label var treated_unequally "Perceived inequality"

********************************************************************************
* STATISTICAL ANALYSIS
* 
********************************************************************************
* set control variables
global controls age age2 edu assets urban_dum

**********************************************************************************
* estimation for men below 40 w/o children
**********************************************************************************
eststo clear

local counter=0
foreach var of varlist treated_unequally   use_violence_d {  // fair_treatment obey_law
  local varlabel: variable label `var'
  eststo: reg `var' polygyny $controls if female==0 & age<40 & nochildren==1, r //& rural==1, r // & assets<5, r
  //estimate predicted values
  margins  , at(polygyny=(0 1)) level(95)
  local counter=`counter' + 1
  marginsplot, recast(scatter) allxlabels level(95) ytitle(`varlabel') ///
    xtitle("Member of polygynous group") title("             (`counter')")
  graph save men_u_nk_`var', replace
  //estimate first difference
  margins, dydx(polygyny) level(95)
  marginsplot, recast(scatter) allxlabels level(95) ytitle(`varlabel') ///
  xtitle("Member of polygynous group") title("             (`counter')")
  graph save fd_men_u_nk_`var', replace
}

**********************************************************************************
* estimation for men above 40 
**********************************************************************************
local counter=2
foreach var of varlist treated_unequally use_violence_d {
  local varlabel: variable label `var'
  eststo: reg `var' polygyny $controls if female==0 & age>40 , r //& rural==1, r // & assets<5, r
  //estimate predicted values
  margins  , at(polygyny=(0 1)) level(95)
  local counter=`counter' + 1
  marginsplot, recast(scatter) allxlabels level(95) ytitle(`varlabel') ///
    xtitle("Member of polygynous group") title("             (`counter')")
  //estimate first difference
  graph save men_a_`var', replace
    margins, dydx(polygyny) level(95)
  marginsplot, recast(scatter) allxlabels level(95) ytitle(`varlabel') ///
  xtitle("Member of polygynous group") title("             (`counter')")
  graph save fd_men_a_`var', replace
}

**********************************************************************************
* estimation for women 
**********************************************************************************
local counter=4
*works: fair_treatment security_better treated_unequally obey_law 
foreach var of varlist treated_unequally  use_violence_d {
  local varlabel: variable label `var'
  eststo: reg `var' polygyny $controls if female==1  , r //& rural==1, r // & assets<5, r
  //estimate predicted values
  margins  , at(polygyny=(0 1)) level(95)
  local counter=`counter' + 1
  marginsplot, recast(scatter) allxlabels level(95) ytitle(`varlabel') ///
    xtitle("Member of polygynous group") title("             (`counter')")
  graph save wo_`var', replace
  //estimate first difference
  margins, dydx(polygyny) level(95)
  marginsplot, recast(scatter) allxlabels level(95) ytitle(`varlabel') ///
  xtitle("Member of polygynous group") title("             (`counter')")
  graph save fd_wo_`var', replace
}

**********************************************************************************
* create regression table
**********************************************************************************

esttab using poly_afro_all.rtf, b(2) se(2) r2(2) aic bic label title("") order() ///
  onecell compress nogaps replace drop(_cons ) star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

**********************************************************************************
* combine predicted values graphs
**********************************************************************************
graph combine men_u_nk_treated_unequally.gph men_u_nk_use_violence_d.gph, title("            Men below 40 years" "            without children") iscale(1) c(1) r(2) 
graph save men_u_nk, replace
graph combine men_a_treated_unequally.gph men_a_use_violence_d.gph, title(" " "              Men above 40 years") iscale(1) c(1) r(2)
graph save men_a, replace
graph combine wo_treated_unequally.gph wo_use_violence_d.gph, title(" " "            Women") iscale(1) c(1) r(2)
graph save wo, replace

graph combine men_u_nk.gph men_a.gph wo.gph, col(3)
graph export afro_all.png, replace width(3000) height(2000)

**********************************************************************************
* combine first difference graphs
**********************************************************************************
graph combine fd_men_u_nk_treated_unequally.gph fd_men_u_nk_use_violence_d.gph, title("            Men below 40 years" "            without children") iscale(1) c(1) r(2) 
graph save fd_men_u_nk, replace
graph combine fd_men_a_treated_unequally.gph fd_men_a_use_violence_d.gph, title(" " "              Men above 40 years") iscale(1) c(1) r(2)
graph save fd_men_a, replace
graph combine fd_wo_treated_unequally.gph fd_wo_use_violence_d.gph, title(" " "            Women") iscale(1) c(1) r(2)
graph save fd_wo, replace

graph combine fd_men_u_nk.gph fd_men_a.gph fd_wo.gph, col(3)
graph export fd_afro_all.png, replace width(3000) height(2000)


//End of file



