********************************************************************************
********************************************************************************
*
* Title: Polygynous Neighbors, Excess Men and Intergroup Conflict in Rural Africa
* Authors: Carlo Koos, Clara Neupert-Wentz
* Publication: Journal of Conflict Resolution
*
* Replication Files for Graphs and Tables in the Main Text and Appendix
*
********************************************************************************
********************************************************************************
clear
cd "<SPECIFY DIRECTORY>"
use polygyny_intergroup_conflict_final.dta
********************************************************************************
* DESCRPITIVE PLOTS
* Note 1: figures 1 and 2 have been produced in qGIS
* Note 2: we used the STATA graph scheme "plotplainblind" which you can but need
*         not use
********************************************************************************

********************************************************************************
* Figure 3: Distribution of explanatory variable (percentage of shared border
*           with neighbouring polygynous groups
********************************************************************************
hist rsh_p_pg, title() percent bin(10) gap(10)
graph export figure_03.png, replace width(5000)

********************************************************************************
* Figure 4: Distribution of outcome variable 
********************************************************************************
hist acl_com if acl_com<40, width(1) start(0) percent gap(10) title("(a) ACLED events") xtitle(Number of events) 
graph save dist_acl_com, replace

hist acl_com50 if acl_com<40, width(1) start(0) percent gap(10) title("(b) ACLED events, 50km buffer") xtitle(Number of events) 
graph save dist_acl_com50, replace

hist ged_com if ged_com<40, width(1) start(0) percent gap(10) title("(c) UCDP-GED events") xtitle(Number of events) 
graph save dist_ged_com, replace

hist ged_com50 if ged_com<40, width(1) start(0) percent gap(10) title("(d) UCDP-GED events, 50km buffer") xtitle(Number of events) 
graph save dist_ged_com50, replace

graph combine dist_acl_com.gph dist_acl_com50.gph dist_ged_com.gph dist_ged_com50.gph, xcommon ycommon iscale(0.8) 
graph export figure_04.png, replace width(3000) height(2500)

********************************************************************************
* STATISTICAL ANALYSIS
* 
********************************************************************************
* set global variables
global expvar rsh_p_pg // explanatory variable: percentage of common border with polygynous neighbouring groups
global in_marriage in_pg // dummy whether observed group is polygynous
global controls     lnkm2group lpop60 sead mean_elev mean_suit malaria  empire distemp city1400 distcon lnslexports1 share_muslim agri_intense // standard set of 
global controls_red lnkm2group lpop60      mean_elev mean_suit          empire distemp city1400 distcon lnslexports1 share_muslim agri_intense // reduced set of control variables in case models would not converge

********************************************************************************
* Table 1: Polygynous neighbouring groups and intergroup conflict events
********************************************************************************
eststo clear
eststo: nbreg acl_com $expvar $in_marriage lnkm2group lpop60 i.ccode, cluster(ccode) difficult
eststo: nbreg acl_com $expvar $in_marriage $controls         i.ccode, cluster(ccode) difficult
eststo: nbreg ged_com $expvar $in_marriage lnkm2group lpop60 i.ccode, cluster(ccode) difficult
eststo: nbreg ged_com $expvar $in_marriage $controls         i.ccode, cluster(ccode) difficult

esttab using table_01.rtf, b(2) se(2) aic bic pr2 label title("Table 1: Polygynous neighbouring groups and intergroup conflict events") ///
  onecell compress nogaps replace drop(_cons) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order($expvar $in_marriage lnkm2group lpop60 distcon $controls) obslast ///
  indicate("Country FE= *.ccode") ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")

********************************************************************************
* Table 2: Polygynous neighbouring groups and intergroup conflict events
*          in 50km-buffer zone
********************************************************************************
eststo clear
eststo: nbreg acl_com50 $expvar $in_marriage lnkm2group lpop60 i.ccode, cluster(ccode) difficult
eststo: nbreg acl_com50 $expvar $in_marriage $controls         i.ccode, cluster(ccode) difficult
eststo: nbreg ged_com50 $expvar $in_marriage lnkm2group lpop60 i.ccode, cluster(ccode) difficult
eststo: nbreg ged_com50 $expvar $in_marriage $controls         i.ccode, cluster(ccode) difficult

esttab using table_02.rtf, b(2) se(2) aic bic pr2 label title("Table 2: Polygynous neighbouring groups and intergroup conflict events in 50km-buffer zone") ///
  onecell compress nogaps replace drop(_cons) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order($expvar $in_marriage lnkm2group lpop60 distcon $controls) obslast ///
  indicate("Country FE= *.ccode") ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")

********************************************************************************
* Figure 5: Predicted number of conflict events
*           tables 1 and 2
********************************************************************************
* panel a: acled events
eststo: nbreg acl_com $expvar $in_marriage $controls i.ccode, cluster(ccode) difficult
margins, at(rsh_p_pg=(0(.1)1))  level(90) 
marginsplot, recast(line) recastci(rarea) allxlabels level(90) xtitle("% of border shared with polygynous groups") ytitle("Predicted number of conflict events") title("     (a) ACLED events") 
graph save aclcom_pr_rsh_pg, replace

* panel b: acled events, 50km buffer
eststo: nbreg acl_com50 $expvar $in_marriage $controls i.ccode, cluster(ccode) difficult
margins, at(rsh_p_pg=(0(.1)1))  level(90)
marginsplot, recast(line) recastci(rarea) allxlabels level(90) xtitle("% of border shared with polygynous groups") ytitle("Predicted number of conflict events") title("     (b) ACLED events, 50km buffer") 
graph save aclcom50_pr_rsh_pg, replace

* panel c: UCDP-GED events
eststo: nbreg ged_com $expvar $in_marriage $controls i.ccode, cluster(ccode) difficult
margins, at(rsh_p_pg=(0(.1)1))  level(90) 
marginsplot, recast(line) recastci(rarea) allxlabels level(90) xtitle("% of border shared with polygynous groups") ytitle("Predicted number of conflict events") title("     (c) UCDP-GED events") 
graph save gedcom_pr_rsh_pg, replace

* panel d: UCDP-GED events, 50km buffer
eststo: nbreg ged_com50 $expvar $in_marriage $controls i.ccode, cluster(ccode) difficult
margins, at(rsh_p_pg=(0(.1)1))  level(90)
marginsplot, recast(line) recastci(rarea) allxlabels level(90) xtitle("% of border shared with polygynous groups") ytitle("Predicted number of conflict events") title("     (d) UCDP-GED events, 50km buffer") 
graph save gedcom50_pr_rsh_pg, replace

graph combine aclcom_pr_rsh_pg.gph aclcom50_pr_rsh_pg.gph gedcom_pr_rsh_pg.gph gedcom50_pr_rsh_pg.gph, ycommon iscale(.6) c(2) r(1)
graph export figure_05.png, replace width(3000) height(2500)

********************************************************************************
*
* APPENDIX
* 
********************************************************************************

********************************************************************************
* Table A1: Summary statistics
********************************************************************************
eststo clear
estpost summarize acl_com acl_com50 ged_com ged_com50 acl_state ged_state $expvar $in_marriage $controls
esttab using table_A01.rtf, b(2) se(2) replace cells("mean sd min max count") noobs label ///
  title("Table A1: Summary Statistics") onecell compress

********************************************************************************
* Table A2: Main models including spatial lags and region fixed effects
********************************************************************************
eststo clear
eststo: nbreg acl_com    spl_acl_com   $expvar $in_marriage $controls region_*, cluster(ccode) difficult
eststo: nbreg acl_com50  spl_acl_com50 $expvar $in_marriage $controls region_*, cluster(ccode) difficult
eststo: nbreg ged_com    spl_ged_com   $expvar $in_marriage $controls region_*, cluster(ccode) difficult
eststo: nbreg ged_com50  spl_ged_com50 $expvar $in_marriage $controls region_*, cluster(ccode) difficult

esttab using table_A02.rtf, b(2) se(2) aic bic pr2 label title("Table A2: Main models including spatial lags and region fixed effects") ///
  onecell compress nogaps replace drop(_cons) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order($expvar $in_marriage lnkm2group lpop60 distcon $controls) obslast ///
  indicate("Region FE= region_*" "Spatial lags=spl_*") ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")

********************************************************************************
* Table A3: Main Models with Outcome Variable cleaned of Conflicts between 
*           Ethnic Sub-Groups
* Note that we had to drop two variables from this model in order
* to achieve convergence in the negative binomial model: 
* (1) distance to sea and (2) malaria stability index
********************************************************************************
eststo clear 
eststo: nbreg gedinf   $expvar $in_marriage $controls_red i.ccode, cluster(ccode) difficult
eststo: nbreg acl_ninf $expvar $in_marriage $controls_red i.ccode, cluster(ccode) difficult
esttab using table_A03.rtf, b(2) se(2) aic bic pr2 label title("Table A3: Main Models with Outcome Variable cleaned of Conflicts between Ethnic Sub-Groups") ///
  onecell compress nogaps replace drop(_cons) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order($expvar $in_marriage lnkm2group lpop60 distcon $controls_red) obslast ///
  indicate("Country FE= *.ccode" ) ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")
  
********************************************************************************
* Table A4: Main Models Using the EA’s 3-Level Indicator for Polygyny 
* Note that we had to drop two variables from this model in order
* to achieve convergence in the negative binomial model: 
* (1) distance to sea and (2) malaria stability index
********************************************************************************
eststo clear
eststo: nbreg acl_com rsh_p_pl rsh_p_pg i.poly $controls_red i.ccode, cluster(ccode) difficult 
eststo: nbreg ged_com rsh_p_pl rsh_p_pg i.poly $controls_red i.ccode, cluster(ccode) difficult 
esttab using table_A04.rtf, b(2) se(2) aic bic pr2 label title("Table A4: Main Models Using the EAs 3-Level Indicator for Polygyny") ///
  onecell compress nogaps replace drop(_cons) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order() obslast ///
  indicate("Country FE= *.ccode" ) ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")

********************************************************************************
* Table A5: State-Based Conflict Events as Outcome Variable
********************************************************************************
eststo clear
eststo: nbreg acl_state $in_marriage $controls i.ccode, cluster(ccode) 
eststo: nbreg ged_state $in_marriage $controls i.ccode*, cluster(ccode) 
esttab using table_A05.rtf, b(2) se(2) aic bic pr2 label title("Table A5: State-Based Conflict Events as Outcome Variable") ///
  onecell compress nogaps replace drop(_cons ) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order() obslast ///
  indicate("Country FE = *.ccode" ) ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")

********************************************************************************
* Table A6: CEM Coarsened Exact Matching
*           Polygynous Neighboring Groups and Intergroup Conflict 
*           Events using the Matched Sample
********************************************************************************
* recode polygynous neighbors variables into control (0-50 percent shared borders) and treatment (90.1-100 percent shared borders)
* refer to the appendix for details on the rationale of CEM and coding
recode rsh_p_pg (0/.50=0) (.5000001/.9=.) (.9000001/1=1), gen(poly_cem)
label var poly_cem "Polygynous neighbors (>90%)"

* check imbalance and match according to treatment indicator "poly_cem"
imb lnkm2group lpop60 distcon in_pg region_n region_s region_c region_e region_w if poly_cem!=., treat(poly_cem)
cem lnkm2group(1.83 2.69 3.59) lpop60(10.63 11.69 12.63) distcon(.15 .31 .57) region_n(1) region_s(1) region_c(1) region_e(1) region_w(1) if poly_cem!=., treat(poly_cem) showbreaks
imb lnkm2group lpop60 distcon  region_n region_s region_c region_e region_w if cem_matched==1 & poly_cem!=., treat(poly_cem)

* run estimations and create table
eststo clear
eststo: nbreg acl_com poly_cem $in_marriage $controls i.ccode [iweight=cem_weights], cluster(ccode)
// note that we had to exchange country FE to region FE in the GED model to allow the nbreg model to converge
eststo: nbreg ged_com poly_cem $in_marriage $controls region_* [iweight=cem_weights], cluster(ccode)
esttab using table_A06.rtf, b(2) se(2) aic bic pr2 label title("Table A6. Polygynous Neighboring Groups and Intergroup Conflict Events using the Matched Sample") ///
  onecell compress nogaps replace drop(_cons) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order(poly_cem $in_marriage lnkm2group lpop60 distcon $controls) obslast ///
  indicate("Country FE= *.ccode" "Region FE=region_*") ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country. Note that we had to change country FE to region FE in model 2 to allow the model to converge with the reduced sample size.")

********************************************************************************
* Table A7: Polygynous Neighboring Groups and Intergroup Conflict Events 
*           including Post-Treatment Variables†
********************************************************************************
label var polity_5y "Polity (1990-95) avg."
label var polity_up5 "Polity up >2 (1990-95)"
label var gdp_diff5 "GDPpc (1990/95) %change"
label var wikilegal "Legal polygamy"
label var wikilegcust "Customary law polygamy"
label var wstatscale "WomanStats scale"

eststo clear
eststo: nbreg acl_com $expvar $in_marriage polity_5y polity_up5 gdp_diff5 $controls i.ccode, cluster(ccode)
eststo: nbreg acl_com $expvar $in_marriage wikilegal wikilegcust wstatscale $controls i.ccode, cluster(ccode)
eststo: nbreg acl_com $expvar $in_marriage polity_5y polity_up5 gdp_diff5 wikilegal wikilegcust $controls i.ccode, cluster(ccode)
esttab using table_A07.rtf, b(2) se(2) aic bic pr2 label title("Polygynous Neighboring Groups and Intergroup Conflict Events including Post-Treatment Variables") ///
  onecell compress nogaps replace drop(_cons )  star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  indicate("Country FE= *.ccode" "Geographic controls= lnkm2group lpop60 mean_elev mean_suit sead  malaria" "Historical controls= empire distemp city1400 distcon lnslexports1") ///
  order($expvar $in_marriage polity_5y polity_up5  gdp_diff5  wikilegal wikilegcust wstatscale $controls )  obslast ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")

********************************************************************************
* Table A8: Polygynous Neighboring Groups and Intergroup Conflict Events using 
*           the Number of Polygynous Neighbors (instead of the Percentage of 
*           Shared Border)
********************************************************************************
label var no_nb_po_g "Polygynous neighbors (number)"

eststo clear
eststo: nbreg acl_com   no_nb_po_g $in_marriage lnkm2group lpop60 distcon i.ccode, cluster(ccode)
eststo: nbreg acl_com   no_nb_po_g $in_marriage $controls i.ccode, cluster(ccode)
eststo: nbreg acl_com50 no_nb_po_g $in_marriage lnkm2group lpop60 distcon i.ccode, cluster(ccode)
eststo: nbreg acl_com50 no_nb_po_g $in_marriage $controls i.ccode, cluster(ccode)

esttab using table_A08.rtf, b(2) se(2) aic bic pr2 label title("Table A8. Polygynous Neighboring Groups and Intergroup Conflict Events using the Number of Polygynous Neighbors (instead of the Percentage of Shared Border)") ///
  onecell compress nogaps replace drop(_cons) star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
  order(no_nb_po_g $in_marriage lnkm2group lpop60 distcon $controls) obslast ///
  indicate("Country FE= *.ccode") ///
  mgroups("All conflicts" "Conflicts near border", pattern(1 0  1 0)) ///
  note("Outcome variable: number of conflict events per ethnic group territory. Robust standard errors clustered by country.")


  
// End of file
